==> RobinCar2_0.2.0.tar.gz: RobinCar2/tests/testthat/_snaps/survival_score.md <==
# h_lr_score_no_strata_no_cov works as expected with default options

    structure(0.0895537761860842, sigma_l2 = 0.17706769289317, se_theta_l = 0.15738484553678, n = 228L)

# h_lr_score_no_strata_no_cov works as expected with custom n

    structure(0.051045652426068, sigma_l2 = 0.100928584949107, se_theta_l = 0.15738484553678, n = 400)

# h_lr_score_no_strata_no_cov works as expected when not using ties factor

    structure(0.00479534279339572, sigma_l2 = 0.158585973213507, se_theta_l = 0.166303040954794, n = 228L)

# h_lr_score_strat works as expected with default options

    structure(0.0896871248297144, sigma_l2 = 0.169145720705825, se_theta_l = 0.161382546477903, n = 227L)

# h_lr_score_strat works as expected when not using ties factor

    structure(0.0896871248297144, sigma_l2 = 0.169404689852017, se_theta_l = 0.161259146456279, n = 227L)

# h_lr_score_cov works as expected with default options

    structure(0.0851266162073163, se_theta_l = 0.156797551454514, sigma_l2 = 0.175748674116587, n = 228L)

# h_lr_score_cov works as expected when not using ties factor

    structure(0.0851266162073163, se_theta_l = 0.156595350460101, sigma_l2 = 0.176209700432439, n = 228L)

# h_lr_score_cov works when using the unadjusted standard error option

    structure(0.0850667744102501, se_theta_l = 0.159015041100831, sigma_l2 = 0.170735177622095, n = 228L)

---

    structure(0.0850667744102501, se_theta_l = 0.156579398029655, sigma_l2 = 0.176173801156959, n = 228L)

# h_lr_score_strat_cov works as expected with default options

    structure(0.0897521729142622, se_theta_l = 0.161382421810696, sigma_l2 = 0.169145459377487, n = 227L)

# h_lr_score_strat_cov works as expected when not using ties factor

    structure(0.0897521729142622, se_theta_l = 0.161259022074831, sigma_l2 = 0.169404428523679, n = 227L)

# h_lr_score_strat_cov works as expected with unadjusted standard error

    structure(0.089793780031155, se_theta_l = 0.164884345428146, sigma_l2 = 0.162036005256482, n = 227L)

---

    structure(0.089793780031155, se_theta_l = 0.164884345428146, sigma_l2 = 0.162036005256482, n = 227L)

---

    structure(0.089793780031155, se_theta_l = 0.161258812068077, sigma_l2 = 0.169403987295021, n = 227L)

==> RobinCar2_0.2.1.tar.gz: RobinCar2/tests/testthat/_snaps/survival_score.md <==
# h_lr_score_no_strata_no_cov works as expected with default options

    structure(0.0895537761860842, sigma_l2 = 0.17706769289317, se_theta_l = 0.15738484553678, n = 228L)

# h_lr_score_no_strata_no_cov works as expected with custom n

    structure(0.051045652426068, sigma_l2 = 0.100928584949107, se_theta_l = 0.15738484553678, n = 400)

# h_lr_score_no_strata_no_cov works as expected when not using ties factor

    structure(0.00479534279339572, sigma_l2 = 0.158585973213507, se_theta_l = 0.166303040954794, n = 228L)

# h_lr_score_strat works as expected with default options

    structure(0.0896871248297144, sigma_l2 = 0.169145720705825, se_theta_l = 0.161382546477903, n = 227L)

# h_lr_score_strat works with multiple strata variables

    structure(0.0896871248297144, sigma_l2 = 0.169145720705825, se_theta_l = 0.161382546477903, n = 227L)

# h_lr_score_strat works as expected when not using ties factor

    structure(0.0896871248297144, sigma_l2 = 0.169404689852017, se_theta_l = 0.161259146456279, n = 227L)

# h_lr_score_cov works as expected with default options

    structure(0.0851266162073163, se_theta_l = 0.156797551454514, sigma_l2 = 0.175748674116587, n = 228L)

# h_lr_score_cov works as expected when not using ties factor

    structure(0.0851266162073163, se_theta_l = 0.156595350460101, sigma_l2 = 0.176209700432439, n = 228L)

# h_lr_score_cov works when using the unadjusted standard error option

    structure(0.0850667744102501, se_theta_l = 0.159015041100831, sigma_l2 = 0.170735177622095, n = 228L)

---

    structure(0.0850667744102501, se_theta_l = 0.156579398029655, sigma_l2 = 0.176173801156959, n = 228L)

# h_lr_score_cov works with a single factor covariate

    structure(0.0889518680173707, se_theta_l = 0.157769376630947, sigma_l2 = 0.176637348077421, n = 227L)

# h_lr_score_strat_cov works as expected with default options

    structure(0.0897521729142622, se_theta_l = 0.161382421810696, sigma_l2 = 0.169145459377487, n = 227L)

# h_lr_score_strat_cov works with multiple strata variables

    structure(0.0897521729142622, se_theta_l = 0.161382421810696, sigma_l2 = 0.169145459377487, n = 227L)

# h_lr_score_strat_cov works as expected when not using ties factor

    structure(0.0897521729142622, se_theta_l = 0.161259022074831, sigma_l2 = 0.169404428523679, n = 227L)

# h_lr_score_strat_cov works as expected with unadjusted standard error

    structure(0.089793780031155, se_theta_l = 0.164884345428146, sigma_l2 = 0.162036005256482, n = 227L)

---

    structure(0.089793780031155, se_theta_l = 0.164884345428146, sigma_l2 = 0.162036005256482, n = 227L)

---

    structure(0.089793780031155, se_theta_l = 0.161258812068077, sigma_l2 = 0.169403987295021, n = 227L)
